import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:syncfusion_flutter_maps/maps.dart';

class _ChoroplethMapState extends State {
  late MapShapeSource mapShapeSource;

  @override
  void initState() {
    super.initState();
    getRelation().then((geojsonData) {
      setState(() {
        mapShapeSource = MapShapeSource.geoJson(
          geojsonData,
          shapeDataField: 'features',
          primaryValueMapper: (Map<String, dynamic> shapeData) {
            return shapeData['Mjøsa'];
          },
        );
      });
    }).catchError((error) {
      throw Exception('Failed to retrieve geojson data');
    });
  }

  @override
  Widget build(BuildContext context) {
    return SfMaps(
      layers: [
        MapShapeLayer(
        source: mapShapeSource,
        strokeColor: Colors.white30,
        legend: const MapLegend.bar(MapElement.shape,
            position: MapLegendPosition.bottom,
            segmentSize: Size(55.0, 9.0)
        )
        ),
      ],
    );
  }

  Future<String> getRelation() async {
    final response = await http.get(Uri.parse('get_relation'));
    if (response.statusCode == 200) {
      return response.body;
    } else {
      throw Exception('Failed to retrieve geojson data');
    }
  }
}
